@@ -7,7 +7,7 @@ import gitlab
 class Gitlab():
 
     def __init__(self, api_url, **kwargs):
-        self.gitlab = gitlab.Gitlab(api_url, kwargs)
+        self.gitlab = gitlab.Gitlab(api_url, **kwargs)
 
     def is_gitlab(self):
         if os.environ.get('CI', 'false') == 'true':
@@ -58,7 +58,7 @@ class Gitlab():
             if e.response_code == 404:
                 prj.variables.create({'key': 'BUILD_NUMBER', 'value': '0'})
                 return
-        var.value = var.value + 1
+        var.value = str(int(var.value) + 1)
         var.save()
 
-        return var.value
+        return int(var.value)
